# add_tmdl { #powerbpy.add_tmdl }

`add_tmdl`



## Functions

| Name | Description |
| --- | --- |
| [add_tmdl_dataset](#powerbpy.add_tmdl.add_tmdl_dataset) | Add a locally stored TMDL file to the dashboard |

### add_tmdl_dataset { #powerbpy.add_tmdl.add_tmdl_dataset }

```python
add_tmdl.add_tmdl_dataset(
    dashboard_path,
    data_path=None,
    add_default_datetable=True,
)
```

Add a locally stored TMDL file to the dashboard

#### Parameters {.doc-section .doc-section-parameters}

| Name                  | Type    | Description                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                | Default    |
|-----------------------|---------| |------------|
| dashboard_path        | str     | The path where the dashboard files are stored. (This is the top level directory containing the .pbip file and Report and SemanticModel folders).                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           | _required_ |
| data_path             | str     | The path where the tmdl file is stored.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    | `None`     |
| add_default_datetable | boolean | Do you want the TMDL file you add to be our team's custom date table? This will allow you to create your own date heirarchies instead of using time intelligence  TMDL is a data storage format automatically created by power BI consisting of a table and column definitions and the M code used to generate the dataset.  In practice this means that you can copy datasets between dashboards. You can use this function to automatically copy the TMDL files at scale Potential pitfalls: M needs full paths to load data. If the new dashboard doesn't have access to the same data as the old dashboard, the data copying may fail. | `True`     |